Determines the closest font matching a description per the CSS Fonts Level 3 specification.
Functions
- find_
best_ match - This follows CSS Fonts Level 3  5.2 [1].
Determines the closest font matching a description per the CSS Fonts Level 3 specification.